@@ -1,4 +1,5 @@
-# Copyright 2012-2018 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright 2012-2021 CERN
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,17 +15,19 @@
 #
 # Authors:
 # - Thomas Beermann <thomas.beermann@cern.ch>, 2012-2017
-# - Martin Barisits <martin.barisits@cern.ch>, 2012-2018
+# - Martin Barisits <martin.barisits@cern.ch>, 2012-2021
 # - Angelos Molfetas <Angelos.Molfetas@cern.ch>, 2012
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2017
-# - Vincent Garonne <vgaronne@gmail.com>, 2012-2018
+# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2018
+# - Vincent Garonne <vincent.garonne@cern.ch>, 2012-2018
 # - Ralph Vigne <ralph.vigne@cern.ch>, 2012-2013
 # - Cedric Serfon <cedric.serfon@cern.ch>, 2013-2020
-# - Wen Guan <wguan.icedew@gmail.com>, 2014-2015
-# - Tobias Wegner <twegner@cern.ch>, 2018
+# - Wen Guan <wen.guan@cern.ch>, 2014-2015
+# - Tobias Wegner <twegner@cern.ch>, 2018-2019
+# - Frank Berghaus <berghaus@cern.ch>, 2018
 # - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018-2019
-#
-# PY3K COMPATIBLE
+# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
+# - Patrick Austin <patrick.austin@stfc.ac.uk>, 2020
+# - Eric Vaandering <ewv@fnal.gov>, 2020
 
 """
     Exceptions used with Rucio.
@@ -564,13 +567,13 @@ class RSEAccessDenied(RucioException):
         self.error_code = 49
 
 
-class RSEBlacklisted(RucioException):
+class RSEWriteBlocked(RucioException):
     """
     RucioException
     """
     def __init__(self, *args, **kwargs):
-        super(RSEBlacklisted, self).__init__(*args, **kwargs)
-        self._message = "RSE excluded due to write blacklisting."
+        super(RSEWriteBlocked, self).__init__(*args, **kwargs)
+        self._message = "RSE excluded; not available for writing."
         self.error_code = 50
 
 
@@ -1002,3 +1005,23 @@ class SubscriptionWrongParameter(RucioException):
         super(SubscriptionWrongParameter, self).__init__(*args, **kwargs)
         self._message = "Subscription wrong parameters"
         self.error_code = 95
+
+
+class VONotFound(RucioException):
+    """
+    Requested VO does not exist.
+    """
+    def __init__(self, *args, **kwargs):
+        super(VONotFound, self).__init__(*args, **kwargs)
+        self.message = 'The requested VO does not exist'
+        self.error_code = 96
+
+
+class UnsupportedAccountName(RucioException):
+    """
+    Requested account name is not supported for users.
+    """
+    def __init__(self, *args, **kwargs):
+        super(UnsupportedAccountName, self).__init__(*args, **kwargs)
+        self.message = 'The requested account name cannot be used'
+        self.error_code = 97
