@@ -47,8 +47,10 @@ import datetime
 import errno
 import getpass
 import hashlib
+import io
 import json
 import logging
+import mmap
 import os
 import os.path
 import re
@@ -59,6 +61,7 @@ import threading
 import time
 import zlib
 from enum import Enum
+from functools import partial
 from uuid import uuid4 as uuid
 from xml.etree import ElementTree
 
@@ -229,7 +232,9 @@ def set_checksum_value(file, checksum_names_list):
 
 def adler32(file):
     """
-    An Adler-32 checksum is obtained by calculating two 16-bit checksums A and B and concatenating their bits into a 32-bit integer. A is the sum of all bytes in the stream plus one, and B is the sum of the individual values of A from each step.
+    An Adler-32 checksum is obtained by calculating two 16-bit checksums A and B
+    and concatenating their bits into a 32-bit integer. A is the sum of all bytes in the
+    stream plus one, and B is the sum of the individual values of A from each step.
 
     :param file: file name
     :returns: Hexified string, padded to 8 values.
@@ -238,14 +243,31 @@ def adler32(file):
     # adler starting value is _not_ 0
     adler = 1
 
+    can_mmap = False
     try:
-        with open(file, 'rb') as openFile:
-            for line in openFile:
-                adler = zlib.adler32(line, adler)
-    except Exception as e:
-        raise Exception('FATAL - could not get Adler32 checksum of file %s - %s' % (file, e))
+        with open(file, 'r+b') as f:
+            can_mmap = True
+    except:
+        pass
 
-    # backflip on 32bit
+    try:
+        # use mmap if possible
+        if can_mmap:
+            with open(file, 'r+b') as f:
+                m = mmap.mmap(f.fileno(), 0)
+                # partial block reads at slightly increased buffer sizes
+                for block in iter(partial(m.read, io.DEFAULT_BUFFER_SIZE * 8), b''):
+                    adler = zlib.adler32(block, adler)
+        else:
+            with open(file, 'rb') as f:
+                # partial block reads at slightly increased buffer sizes
+                for block in iter(partial(f.read, io.DEFAULT_BUFFER_SIZE * 8), b''):
+                    adler = zlib.adler32(block, adler)
+
+    except Exception as e:
+        raise Exception('FATAL - could not get Adler-32 checksum of file %s: %s' % (file, e))
+
+    # backflip on 32bit -- can be removed once everything is fully migrated to 64bit
     if adler < 0:
         adler = adler + 2 ** 32
 
